tzdata: Provider of IANA time zone data
=======================================

Description
-----------

Provider of IANA time zone data

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/tzdata/

